@@ -17,7 +17,9 @@ import numpy                        as np
 import OpenGL.GL                    as gl
 
 import fsl.utils.idle               as idle
+
 import fsl.utils.notifier           as notifier
+import fsl.utils.transform          as transform
 import fsleyes_widgets.utils.status as status
 import fsleyes.strings              as strings
 from . import data                  as texdata
@@ -38,6 +40,7 @@ class TextureBase(object):
 
        name
        handle
+       target
        ndim
        nvals
        isBound
@@ -121,6 +124,14 @@ class TextureBase(object):
         return self.__texture
 
 
+    @property
+    def target(self):
+        """Returns the type of this texture - ``GL_TEXTURE_1D``,
+        ``GL_TEXTURE_2D`` or ``GL_TEXTURE_3D``.
+        """
+        return self.__ttype
+
+
     @property
     def ndim(self):
         """Return the number of dimensions of this texture - 1, 2, or 3. """
@@ -487,20 +498,33 @@ class Texture(notifier.Notifier, TextureBase, TextureSettingsMixin):
                  nvals,
                  threaded=False,
                  settings=None,
+                 textureFormat=None,
+                 internalFormat=None,
                  **kwargs):
         """Create a ``Texture``.
 
-        :arg name:     The name of this texture - should be unique.
-        :arg ndims:    Number of dimensions - must be 1, 2 or 3.
-        :arg nvals:    Number of values stored in each texture element.
-        :arg threaded: If ``True``, the texture data will be prepared on a
-                       separate thread (on calls to
-                       :meth:`refresh`). If ``False``, the texture data is
-                       prepared on the calling thread, and the
-                       :meth:`refresh` call will block until it has been
-                       prepared.
-        :arg settings: Additional settings to make available through the
-                       :class:`TextureSettingsMixin`.
+        :arg name:           The name of this texture - should be unique.
+
+        :arg ndims:          Number of dimensions - must be 1, 2 or 3.
+
+        :arg nvals:          Number of values stored in each texture element.
+
+        :arg threaded:       If ``True``, the texture data will be prepared on
+                             a separate thread (on calls to
+                             :meth:`refresh`). If ``False``, the texture data
+                             is prepared on the calling thread, and the
+                             :meth:`refresh` call will block until it has been
+                             prepared.
+
+        :arg settings:       Additional settings to make available through the
+                             :class:`TextureSettingsMixin`.
+
+        :arg textureFormat:  Texture format to use - if not specified, this is
+                             automatically determined. If specified, an
+                             ``internalFormat`` must also be specified.
+
+        :arg internalFormat: Internal texture format to use - if not specified,
+                             this is automatically determined.
 
         All other arguments are passed through to the initial call to
         :meth:`set`.
@@ -508,11 +532,24 @@ class Texture(notifier.Notifier, TextureBase, TextureSettingsMixin):
         .. note:: All subclasses must accept a ``name`` as the first parameter
                   to their ``__init__`` method, and must pass said ``name``
                   through to the :meth:`__init__` method.
+
+        .. note:: In normal cases, the ``textureFormat`` and ``internalFormat``
+                  do not need to be specified - they will be automatically
+                  determined using the :func:`.data.getTextureType` function.
+                  However, there can be instances where a specific texture type
+                  needs to be used. In these instances, it is up to the calling
+                  code to ensure that the texture data can be coerced into
+                  the correct GL data type.
         """
 
         TextureBase         .__init__(self, name, ndims, nvals)
         TextureSettingsMixin.__init__(self, settings)
 
+        if ((textureFormat is not None) and (internalFormat is     None)) or \
+           ((textureFormat is     None) and (internalFormat is not None)):
+            raise ValueError('Both textureFormat and internalFormat '
+                             'must be specified')
+
         self.__ready    = False
         self.__threaded = threaded
 
@@ -535,8 +572,9 @@ class Texture(notifier.Notifier, TextureBase, TextureSettingsMixin):
         self.__voxValXform    = None
         self.__invVoxValXform = None
 
-        self.__texFmt         = None
-        self.__texIntFmt      = None
+        self.__autoTexFmt     = textureFormat is None
+        self.__texFmt         = textureFormat
+        self.__texIntFmt      = internalFormat
         self.__texDtype       = None
 
         # If threading is enabled, texture
@@ -593,6 +631,25 @@ class Texture(notifier.Notifier, TextureBase, TextureSettingsMixin):
         return self.__invVoxValXform
 
 
+    def texCoordXform(self, origShape):
+        """Returns a transformation matrix which can be used to adjust a set of
+        3D texture coordinates so they can index the underlying texture, which
+        may be 2D.
+
+        This implementation returns an identity matrix, but it is overridden
+        by the .Texture2D sub-class, which is sometimes used to store 3D image
+        data.
+
+        :arg origShape: Original data shape.
+        """
+        return np.eye(4)
+
+
+    def invTexCoordXform(self, origShape):
+        """Returns the inverse of :meth:`texCoordXform`. """
+        return transform.invert(self.texCoordXform(origShape))
+
+
     @property
     def shape(self):
         """Return a tuple containing the texture data shape. """
@@ -655,6 +712,20 @@ class Texture(notifier.Notifier, TextureBase, TextureSettingsMixin):
         return self.__preparedData
 
 
+    def shapeData(self, data, oldShape=None):
+        """Shape the data so that it is ready for use as texture data.
+
+        This implementation returns the data unchanged, but it is overridden
+        by the ``Texture2D`` class, which is sometimes used to store 3D image
+        data.
+
+        :arg data:     ``numpy`` array containing the data to be shaped
+        :arg oldShape: Original data shape, if this is a sub-array. If not
+                       provided, taken from ``data``.
+        """
+        return data
+
+
     def set(self, **kwargs):
         """Set any parameters on this ``Texture``. Valid keyword arguments are:
 
@@ -896,7 +967,7 @@ class Texture(notifier.Notifier, TextureBase, TextureSettingsMixin):
         raise NotImplementedError('Must be implemented by subclasses')
 
 
-    def doPatch(data, offset):
+    def doPatch(self, data, offset):
         """Must be overridden by sub-classes to quickly update part of
         the texture data.
 
@@ -937,6 +1008,10 @@ class Texture(notifier.Notifier, TextureBase, TextureSettingsMixin):
         texDtype, texFmt, intFmt = texdata.getTextureType(
             normalise, dtype, nvals)
 
+        if not self.__autoTexFmt:
+            texFmt = self.__texFmt
+            intFmt = self.__texIntFmt
+
         log.debug('Texture (%s) is to be stored as %s/%s/%s '
                   '(normalised: %s)',
                   self.name,
