@@ -109,6 +109,9 @@ messages = TypeDict({
                                         'with same dimensions',
     'actions.copyoverlay.copyDisplay' : 'Copy display properties',
     'actions.copyoverlay.copy4D'      : 'Copy 4D image',
+    'actions.copyoverlay.copyMulti'   : 'Copy all channels/components',
+    'actions.copyoverlay.component'   :
+    'Select the component/channel you want to copy',
 
     'RunScriptAction.runScript' : 'Choose a FSLeyes script to run',
     'RunScriptAction.crash'     : 'The script {} has crashed! Reason: {}',
@@ -304,6 +307,12 @@ messages = TypeDict({
     'An error occurred loading the plugin file.',
     'LoadPluginAction.installError'  :
     'An error occurred installing the plugin file.',
+
+    'FileTreePanel.loadDir'        : 'Load directory',
+    'FileTreePanel.loadCustomTree' : 'Load filetree file',
+    'FileTreePanel.save'           : 'Save notes',
+    'FileListPanel.buildingList'   : 'Building file list ...',
+    'FileListPanel.loading'        : 'Loading files ...',
 })
 
 
@@ -355,6 +364,8 @@ titles = TypeDict({
     'FlirtFileDialog.load'      : 'Load affine transformation',
     'FlirtFileDialog.save'      : 'Save affine transformation',
 
+    'NewImageDialog'            : 'New image',
+
     'PlotListPanel'             : 'Plot list',
     'TimeSeriesControlPanel'    : 'Time series control',
     'HistogramControlPanel'     : 'Histogram control',
@@ -370,6 +381,8 @@ titles = TypeDict({
     'CropImagePanel'             : 'Crop',
     'EditTransformPanel'         : 'Nudge',
 
+    'FileTreePanel'              : 'File tree',
+
     'LocationHistoryPanel.loadError' : 'Error loading location file',
     'LocationHistoryPanel.saveError' : 'Error saving location file',
 
@@ -397,6 +410,8 @@ titles = TypeDict({
     'removeoverlay.unsaved' : 'Remove unsaved image?',
     'reloadoverlay.unsaved' : 'Reload unsaved image?',
 
+    'actions.copyoverlay.component' : 'Select component/channel',
+
     'OrthoPanel.toolMenu'                 : 'Tools',
 
     'OrthoEditProfile.imageChange'        : 'Changing edited image',
@@ -462,6 +477,7 @@ actions = TypeDict({
     'LoadStandardAction'       : 'Add standard',
     'LoadDicomAction'          : 'Add from DICOM',
     'BrowseXNATAction'         : 'Add from XNAT',
+    'NewImageAction'           : 'New image',
     'CopyOverlayAction'        : 'Copy',
     'LoadAtlasAction'          : 'Import new atlas',
     'ClearSettingsAction'      : 'Clear FSLeyes settings',
@@ -518,6 +534,7 @@ actions = TypeDict({
     'CanvasPanel.toggleClusterPanel'        : 'Cluster browser',
     'CanvasPanel.toggleOverlayInfo'         : 'Overlay information',
     'CanvasPanel.toggleClassificationPanel' : 'Melodic IC classification',
+    'CanvasPanel.toggleFileTreePanel'       : 'File tree',
 
     'OrthoPanel.toggleOrthoToolBar'       : 'Ortho toolbar',
     'OrthoPanel.toggleEditMode'           : 'Edit mode',
@@ -616,27 +633,30 @@ labels = TypeDict({
 
     'PlotControlPanel.plotSettings'       : 'General plot settings',
     'PlotControlPanel.customPlotSettings' : 'Custom plot settings',
-    'PlotControlPanel.currentDSSettings'  : 'Plot settings for '
-                                            'selected overlay ({})',
-    'PlotControlPanel.customDSSettings'   : 'Custom plot settings for '
-                                            'selected overlay ({})',
+    'PlotControlPanel.currentDSSettings'  : 'Plot settings for {}',
+    'PlotControlPanel.customDSSettings'   : 'Custom plot settings for {}',
     'PlotControlPanel.xlim'               : 'X limits',
     'PlotControlPanel.ylim'               : 'Y limits',
     'PlotControlPanel.labels'             : 'Labels',
+    'PlotControlPanel.logscale'           : 'Log scale',
+    'PlotControlPanel.invert'             : 'Invert',
+    'PlotControlPanel.autoscale'          : 'Auto scale',
+    'PlotControlPanel.scale'              : 'Axis scale',
+    'PlotControlPanel.offset'             : 'Axis offset',
     'PlotControlPanel.xlabel'             : 'X',
     'PlotControlPanel.ylabel'             : 'Y',
 
-
     'TimeSeriesControlPanel.customPlotSettings' : 'Time series settings',
-    'TimeSeriesControlPanel.customDSSettings'   : 'FEAT settings for '
-                                                  'selected overlay ({})',
+    'TimeSeriesControlPanel.customDSSettings'   : 'Time series settings for '
+                                                  '{}',
 
     'PowerSpectrumControlPanel.customPlotSettings' : 'Power spectrum plot '
                                                      'settings',
+    'PowerSpectrumControlPanel.customDSSettings' : 'Power spectrum '
+                                                   'settings for {}',
 
     'HistogramControlPanel.customPlotSettings' : 'Histogram plot settings',
-    'HistogramControlPanel.customDSSettings'   : 'Histogram settings for '
-                                                  'selected overlay ({})',
+    'HistogramControlPanel.customDSSettings'   : 'Histogram settings for {}',
 
     'FEATModelFitTimeSeries.full' : 'Full model fit',
     'FEATModelFitTimeSeries.cope' : 'COPE{} fit: {}',
@@ -647,6 +667,16 @@ labels = TypeDict({
 
     'FEATResidualTimeSeries'     : 'Residuals',
 
+    'ComplexTimeSeries'   : 'real',
+    'ImaginaryTimeSeries' : 'imaginary',
+    'MagnitudeTimeSeries' : 'magnitude',
+    'PhaseTimeSeries'     : 'phase',
+
+    'ComplexPowerSpectrumSeries'   : 'real',
+    'ImaginaryPowerSpectrumSeries' : 'imaginary',
+    'MagnitudePowerSpectrumSeries' : 'magnitude',
+    'PhasePowerSpectrumSeries'     : 'phase',
+
     'ClusterPanel.clustName'     : 'Z statistics for COPE{} ({})',
 
     'ClusterPanel.index'         : 'Cluster index',
@@ -864,6 +894,19 @@ labels = TypeDict({
     'ResampleDialog.newVoxels'     : 'New shape',
     'ResampleDialog.newPixdims'    : 'New pixdims',
 
+    'NewImageDialog.uchar'         : 'Unsigned char',
+    'NewImageDialog.sshort'        : 'Signed short',
+    'NewImageDialog.sint'          : 'Signed int',
+    'NewImageDialog.float'         : 'Float',
+    'NewImageDialog.double'        : 'Double',
+    'NewImageDialog.ok'            : 'Ok',
+    'NewImageDialog.cancel'        : 'Cancel',
+    'NewImageDialog.dtype'         : 'Data type',
+    'NewImageDialog.shape'         : 'Shape',
+    'NewImageDialog.pixdim'        : 'Dimensions',
+    'NewImageDialog.link'          : 'link with dimensions',
+    'NewImageDialog.affine'        : 'Affine',
+
     'XNATBrowser.ok'        : 'Download',
     'XNATBrowser.cancel'    : 'Cancel',
     'XNATBrowser.choosedir' : 'Choose a download location',
@@ -879,6 +922,17 @@ labels = TypeDict({
 
     'BrowseDicomDialog.load'       : 'Load',
     'BrowseDicomDialog.cancel'     : 'Cancel',
+
+    'FileTreePanel.loadDir'    : 'Load directory',
+    'FileTreePanel.customTree' : 'Load tree file',
+    'FileTreePanel.save'       : 'Save notes',
+    'FileListPanel.notes'      : 'Notes',
+    'FileListPanel.present'    : '\u2713',
+    'VariablePanel.value.none' : '<none>',
+    'VariablePanel.value.any'  : '<any>',
+    'VariablePanel.value.all'  : '<all>',
+
+
 })
 
 
@@ -942,6 +996,8 @@ properties = TypeDict({
     'PlotPanel.yAutoScale' : 'Auto-scale (y axis)',
     'PlotPanel.xLogScale'  : 'Log scale (x axis)',
     'PlotPanel.yLogScale'  : 'Log scale (y axis)',
+    'PlotPanel.invertX'    : 'Invert X axis',
+    'PlotPanel.invertY'    : 'Invert Y axis',
     'PlotPanel.xlabel'     : 'X label',
     'PlotPanel.ylabel'     : 'Y label',
 
@@ -964,6 +1020,20 @@ properties = TypeDict({
     'DataSeries.lineWidth' : 'Line width',
     'DataSeries.lineStyle' : 'Line style',
 
+    'ComplexTimeSeries.plotReal'      : 'Plot real',
+    'ComplexTimeSeries.plotImaginary' : 'Plot imaginary',
+    'ComplexTimeSeries.plotMagnitude' : 'Plot magnitude',
+    'ComplexTimeSeries.plotPhase'     : 'Plot phase',
+
+    'ComplexPowerSpectrumSeries.plotReal'      : 'Plot real',
+    'ComplexPowerSpectrumSeries.plotImaginary' : 'Plot imaginary',
+    'ComplexPowerSpectrumSeries.plotMagnitude' : 'Plot magnitude',
+    'ComplexPowerSpectrumSeries.plotPhase'     : 'Plot phase',
+    'ComplexPowerSpectrumSeries.zeroOrderPhaseCorrection' :
+    'Zero order phase correction (degrees)',
+    'ComplexPowerSpectrumSeries.firstOrderPhaseCorrection' :
+    'First order phase correction (seconds)',
+
     'HistogramSeries.nbins'           : 'Number of bins',
     'HistogramSeries.autoBin'         : 'Automatic histogram binning',
     'HistogramSeries.ignoreZeros'     : 'Ignore zeros',
@@ -972,6 +1042,11 @@ properties = TypeDict({
     'HistogramSeries.dataRange'       : 'Data range',
     'HistogramSeries.showOverlay'     : 'Show 3D histogram overlay',
 
+    'ComplexHistogramSeries.plotReal'      : 'Plot real',
+    'ComplexHistogramSeries.plotImaginary' : 'Plot imaginary',
+    'ComplexHistogramSeries.plotMagnitude' : 'Plot magnitude',
+    'ComplexHistogramSeries.plotPhase'     : 'Plot phase',
+
     'PowerSpectrumSeries.varNorm'     : 'Normalise to unit variance',
 
     'FEATTimeSeries.plotFullModelFit' : 'Plot full model fit',
@@ -1040,6 +1115,8 @@ properties = TypeDict({
     'Volume3DOpts.clipInclination'         : 'Clip Z angle',
     'Volume3DOpts.clipAzimuth'             : 'Clip rotation',
 
+    'ComplexOpts.component' : 'Component',
+
     'MaskOpts.colour'        : 'Colour',
     'MaskOpts.invert'        : 'Invert',
     'MaskOpts.threshold'     : 'Threshold',
@@ -1216,9 +1293,15 @@ choices = TypeDict({
     'SHOpts.colourMode' : {'radius'    : 'Colour by radius',
                            'direction' : 'Colour by direction'},
 
+    'ComplexOpts.component' :{ 'real'  : 'Real',
+                               'imag'  : 'Imaginary',
+                               'mag'   : 'Magnitude',
+                               'phase' : 'Phase'},
+
     'Display.overlayType' : {
         'volume'         : '3D/4D volume',
         'rgb'            : '3D/4D RGB(A) volume',
+        'complex'        : 'Complex volume',
         'mask'           : '3D/4D mask image',
         'mip'            : 'Max intensity projection',
         'label'          : 'Label image',
@@ -1244,6 +1327,13 @@ choices = TypeDict({
                                   'demean'        : 'Demeaned',
                                   'normalise'     : 'Normalised',
                                   'percentChange' : 'Percent changed'},
+
+    'CopyOverlayAction.component' : {'real' : 'Real',
+                                     'imag' : 'Imaginary',
+                                     'R'    : 'R',
+                                     'G'    : 'G',
+                                     'B'    : 'B',
+                                     'A'    : 'A'},
 })
 
 
