@@ -29,6 +29,7 @@ import fsleyes.controls.locationpanel              as locationpanel
 import fsleyes.controls.clusterpanel               as clusterpanel
 import fsleyes.controls.lookuptablepanel           as lookuptablepanel
 import fsleyes.controls.melodicclassificationpanel as melclasspanel
+import fsleyes.controls.filetreepanel              as filetreepanel
 from . import                                         colourbarpanel
 from . import                                         viewpanel
 
@@ -94,6 +95,7 @@ class CanvasPanel(viewpanel.ViewPanel):
        toggleClusterPanel
        toggleLookupTablePanel
        toggleClassificationPanel
+       toggleFileTreePanel
 
 
     .. _canvaspanel-adding-content:
@@ -519,6 +521,14 @@ class CanvasPanel(viewpanel.ViewPanel):
                          canvasPanel=self)
 
 
+    @actions.toggleControlAction(filetreepanel.FileTreePanel)
+    def toggleFileTreePanel(self):
+        """Toggles a :class:`.FileTreePanel`. See
+        :meth:`.ViewPanel.togglePanel`.
+        """
+        self.togglePanel(filetreepanel.FileTreePanel, location=wx.RIGHT)
+
+
     @property
     def sceneOpts(self):
         """Returns the :class:`.SceneOpts` instance used by this
